# EPEL 9.0, PHP 8.0

# Enabled extension
%bcond_without sodium
%bcond_without aspell
%bcond_without freetds
%bcond_without tidy
%bcond_without firebird

# dead library, not planed for now
%bcond_with    imap

Name:       php-extras
Summary:    Additional PHP extensions from the standard PHP distribution
Version:    8.0.30
Release:    2%{?dist}
License:    PHP
URL:        https://www.php.net/
Source0:    https://www.php.net/distributions/php-%{version}.tar.xz

# Security patches
Patch100:   php-cve-2024-11236.patch

BuildRequires: (php-devel >= 8.0 with php-devel < 8.1)
BuildRequires:  php-pdo


%description
PHP is an HTML-embedded scripting language.

This package contains various additional extension for PHP, which
have not been included in the basic PHP package for RHEL.


%if %{with imap}
%package -n php-imap
Summary:       A module for PHP applications that use IMAP

BuildRequires: krb5-devel, openssl-devel, libc-client-devel

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-imap
The php-imap package module will add IMAP (Internet Message Access Protocol)
support to PHP. IMAP is a protocol for retrieving and uploading e-mail messages
on mail servers. PHP is an HTML-embedded scripting language. If you need IMAP
support for PHP applications, you will need to install this package.
%endif


%if %{with tidy}
%package -n php-tidy
Summary:       Standard PHP module provides tidy library support

BuildRequires: libtidy-devel

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-tidy
The php-tidy package contains a dynamic shared object that will
add support for using the tidy library to PHP.
%endif


%if %{with freetds}
%package -n php-pdo-dblib
Summary:        PDO driver Microsoft SQL Server and Sybase databases

BuildRequires:  freetds-devel

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php(pdo-abi) = %{php_pdo_api}

Provides:       php-pdo_dblib, php-pdo_dblib%{?_isa}

%description -n php-pdo-dblib
The php-pdo-dblib package contains a dynamic shared object
that implements the PHP Data Objects (PDO) interface to enable access from
PHP to Microsoft SQL Server and Sybase databases through the FreeTDS libary.
%endif


%if %{with firebird}
%package -n php-pdo-firebird
Summary: PDO driver for Interbase/Firebird databases

# for fb_config command
BuildRequires:  firebird-devel

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php(pdo-abi) = %{php_pdo_api}

Provides:       php-pdo_firebird, php-pdo_firebird%{?_isa}

%description -n php-pdo-firebird
The php-pdo-firebird package contains the PDO driver for
Interbase/Firebird databases.
%endif


%if %{with aspell}
%package -n php-pspell
Summary:       A module for PHP applications for using pspell interfaces

BuildRequires: aspell-devel >= 0.50.0

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-pspell
The php-pspell package contains a dynamic shared object that will add
support for using the pspell library to PHP.
%endif


%if %{with sodium}
%package -n php-sodium
Summary: Wrapper for the Sodium cryptographic library

BuildRequires: pkgconfig(libsodium) >= 1.0.9

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

Provides:      php-pecl(libsodium)         = %{version}
Provides:      php-pecl(libsodium)%{?_isa} = %{version}


%description -n php-sodium
The php-sodium package provides a simple,
low-level PHP extension for the libsodium cryptographic library.
%endif


%prep
%setup -q -n php-%{version}

%patch -P100 -p1 -b .cve11236


%build
for mod in \
%if %{with imap}
    imap \
%endif
%if %{with freetds}
    pdo_dblib \
%endif
%if %{with firebird}
    pdo_firebird \
%endif
%if %{with aspell}
    pspell \
%endif
%if %{with sodium}
    sodium \
%endif
%if %{with tidy}
    tidy \
%endif
; do
    pushd ext/$mod

    %{_bindir}/phpize
    %configure \
       --with-libdir=%{_lib} \
%if %{with imap}
       --with-imap=shared --with-kerberos --with-imap-ssl \
%endif
%if %{with freetds}
       --with-pdo-dblib=shared,%{_prefix} \
%endif
%if %{with firebird}
       --with-pdo-firebird=shared \
%endif
%if %{with aspell}
       --with-pspell=shared \
%endif
%if %{with sodium}
       --with-sodium=shared \
%endif
%if %{with tidy}
       --with-tidy=shared,%{_prefix} \
%endif
       --with-php-config=%{_bindir}/php-config

    make %{?_smp_mflags}

    popd
done


%check
for mod in \
%if %{with imap}
    imap \
%endif
%if %{with freetds}
    pdo_dblib \
%endif
%if %{with firebird}
    pdo_firebird \
%endif
%if %{with aspell}
    pspell \
%endif
%if %{with sodium}
    sodium \
%endif
%if %{with tidy}
    tidy \
%endif
; do
    : Minimal load test for $mod extension
    php -d extension=ext/$mod/modules/$mod.so -m | grep -i "^${mod}$"
done

: skip known failed tests
rm ext/tidy/tests/020.phpt

: upstream test suite for extension without Database
fail=0
for mod in \
%if %{with imap}
    imap \
%endif
%if %{with aspell}
    pspell \
%endif
%if %{with sodium}
    sodium \
%endif
%if %{with tidy}
    tidy \
%endif
; do
    pushd ext/$mod
    : Upstream tests for $mod extension
    make test TESTS="-q --show-diff %{?_smp_mflags}" || fail=1
    popd
done
exit $fail


%install
install -d %{buildroot}%{php_extdir}
install -d %{buildroot}%{php_inidir}

for mod in \
%if %{with imap}
    imap \
%endif
%if %{with freetds}
    pdo_dblib \
%endif
%if %{with firebird}
    pdo_firebird \
%endif
%if %{with aspell}
    pspell \
%endif
%if %{with sodium}
    sodium \
%endif
%if %{with tidy}
    tidy \
%endif
; do
    make -C ext/${mod} install INSTALL_ROOT=%{buildroot}

    cat > %{buildroot}%{php_inidir}/30-${mod}.ini <<EOF
; Enable ${mod} extension module
extension=${mod}
EOF
    cat > files.${mod} <<EOF
%{php_extdir}/${mod}.so
%config(noreplace) %{php_inidir}/30-${mod}.ini
EOF
done


# Notice: PHP License in php-common pulled by each package

%if %{with imap}
%files -n php-imap         -f files.imap
%endif

%if %{with firebird}
%files -n php-pdo-firebird -f files.pdo_firebird
%endif

%if %{with freetds}
%files -n php-pdo-dblib    -f files.pdo_dblib
%endif

%if %{with aspell}
%files -n php-pspell       -f files.pspell
%endif

%if %{with sodium}
%files -n php-sodium       -f files.sodium
%endif

%if %{with tidy}
%files -n php-tidy         -f files.tidy
%endif

%changelog
* Fri Nov 29 2024 Remi Collet <rcollet@redhat.com> - 8.0.30-2
- Fix Integer overflow in the dblib/firebird quoter causing OOB writes
  CVE-2024-11236

* Thu Nov  9 2023 Remi Collet <rcollet@redhat.com> - 8.0.30-1
- rebase to 8.0.30

* Wed Jan 11 2023 Remi Collet <rcollet@redhat.com> - 8.0.20-1
- rebase to 8.0.20

* Mon Feb 21 2022 Remi Collet <rcollet@redhat.com> - 8.0.13-2
- add pdo_firebird extension

* Mon Jan 24 2022 Remi Collet <rcollet@redhat.com> - 8.0.13-1
- update to 8.0.13
- add tidy extension

* Wed Dec  8 2021 Remi Collet <rcollet@redhat.com> - 8.0.12-3
- add pdo_dblib extension

* Tue Dec  7 2021 Remi Collet <rcollet@redhat.com> - 8.0.12-2
- add pspell extension

* Mon Dec  6 2021 Remi Collet <rcollet@redhat.com> - 8.0.12-1
- update to 8.0.12 for EPEL-9, only sodium

* Wed Nov  4 2020 Remi Collet <rcollet@redhat.com> - 7.4.6-1
- rebase to 7.4.6
- drop interbase extension (pdo_firebird still available)

* Tue Sep  8 2020 Remi Collet <rcollet@redhat.com> - 7.3.20-1
- rebase to 7.3.20

* Wed Feb  5 2020 Remi Collet <rcollet@redhat.com> - 7.3.5-1
- initial package for EPEL-8 and php:7.3
